@@ -49,7 +49,7 @@ __license__ = "GPLv2"
 __maintainer__ = "Michael G. Noll"
 __status__ = "Development"
 __url__ = "http://www.michael-noll.com/"
-__version__ = "1.5.8"
+__version__ = "1.5.9"
 
 import base64
 import cgi
@@ -634,7 +634,9 @@ class DeliciousAPI(object):
                         date_str = spans[0].contents[0].strip()
                         timestamp =  datetime.datetime.strptime(date_str, '%d %b %y')
 
-                # extract comments
+                # extract url, title and comments
+                url = u""
+                title = u""
                 comment = u""
                 datas = bookmark_element.findAll("div", attrs={"class": "data"})
                 if datas:
